@@ -2,6 +2,7 @@
 #include "vga.h"
 #include "vgakeyboard.h"
 #include "vgamouse.h"
+#include "vgajoystick.h"
 
 void vga_setchipset(int c) {}
 void vga_setchipsetandfeatures(int c, int par1, int par2) {}
@@ -121,6 +122,37 @@ unsigned char *graph_mem;
 /* new in 1.2.11 */
 int vga_runinbackground_version(void) { return 0; }
 
+/* new in 1.3.1 */
+void joystick_close(int joydev) {};
+char joystick_getaxis(int joydev, int a) { return 0; };
+char joystick_getbutton(int joydev, int b) { return 0; };
+char joystick_getnumaxes(int joydev) { return 0; };
+char joystick_getnumbuttons(int joydev) { return 0; };
+int joystick_init(int joydev, __joystick_output jo) { return -1; };
+void joystick_sethandler(int joydev, __joystick_handler jh) {};
+void joystick_setdefaulthandler(int joydev) {};
+int joystick_update(void) { return 0; };
+
+/* new in 1.4.0 */
+int vga_addtiming(
+	int pixelClock, int HDisplay, int HSyncStart, int HSyncEnd, int HTotal,
+	int VDisplay, int VSyncStart, int VSyncEnd, int VTotal, int flags)
+{ return 0; }
+int vga_changetiming(
+	int pixelClock, int HDisplay, int HSyncStart, int HSyncEnd, int HTotal,
+	int VDisplay, int VSyncStart, int VSyncEnd, int VTotal, int flags)
+{ return 0; }
+int vga_getcurrenttiming(
+	int *pixelClock, int *HDisplay, int *HSyncStart, int *HSyncEnd,
+	int *HTotal, int *VDisplay, int *VSyncStart, int *VSyncEnd, int *VTotal,
+	int *flags)
+{ return 0; }
+int vga_guesstiming(int x, int y, int clue, int arg) { return 0; }
+int vga_addmode(int xdim, int ydim, int cols, int xbytes, int bytespp)
+{ return 0; }
+int vga_getoptmode(int x, int y, int colors, int bytesperpixel, int c)
+{ return 0; }
+
 /* non-public, but used in thrust package */
 int __svgalib_name2number(char *m) { return -1; }
 
