@@ -57,3 +57,6 @@ void gl_setpalette( void *p) {}
 void gl_setrgbpalette( ) {}
 unsigned char *gl_font8x8 = NULL;
 GraphicsContext currentcontext;
+
+/* new in 1.3.1 */
+int gl_printf(int x, int y, const char *fmt, ...) { return 0; }
